==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/CalloutSeriesSelectingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutSeriesSelectingEventArgsDescription } from "./CalloutSeriesSelectingEventArgsDescription";
/**
 * @hidden
 */
export let CalloutSeriesSelectingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalloutSeriesSelectingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CalloutSeriesSelectingEventArgsDescriptionMetadata.a == null) {
                CalloutSeriesSelectingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalloutSeriesSelectingEventArgsDescriptionMetadata.c(CalloutSeriesSelectingEventArgsDescriptionMetadata.a);
            }
            if (a.k(CalloutSeriesSelectingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(CalloutSeriesSelectingEventArgsDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("XValueRef", "(w:XValue,j:xValue,wf:XValue)DataRef");
            a.item("YValueRef", "(w:YValue,j:yValue,wf:YValue)DataRef");
            a.item("ItemRef", "(w:Item,j:item,wf:Item)DataRef");
            a.item("Series", "(j:_internalSeries)ExportedType:Series");
            a.item("SeriesName", "String");
        }
        static d(a) {
            CalloutSeriesSelectingEventArgsDescriptionMetadata.b(a);
            a.ad("CalloutSeriesSelectingEventArgs", () => new CalloutSeriesSelectingEventArgsDescription());
            a.ac("CalloutSeriesSelectingEventArgs", CalloutSeriesSelectingEventArgsDescriptionMetadata.a);
        }
    }
    CalloutSeriesSelectingEventArgsDescriptionMetadata.$t = markType(CalloutSeriesSelectingEventArgsDescriptionMetadata, 'CalloutSeriesSelectingEventArgsDescriptionMetadata');
    CalloutSeriesSelectingEventArgsDescriptionMetadata.a = null;
    return CalloutSeriesSelectingEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/CalloutSeriesSelectingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutSeriesSelectingEventArgsDescription } from "./CalloutSeriesSelectingEventArgsDescription";
/**
 * @hidden
 */
export let CalloutSeriesSelectingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalloutSeriesSelectingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CalloutSeriesSelectingEventArgsDescriptionMetadata.a == null) {
                CalloutSeriesSelectingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalloutSeriesSelectingEventArgsDescriptionMetadata.c(CalloutSeriesSelectingEventArgsDescriptionMetadata.a);
            }
            if (a.k(CalloutSeriesSelectingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(CalloutSeriesSelectingEventArgsDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("XValueRef", "(w:XValue,j:xValue,wf:XValue)DataRef");
            a.item("YValueRef", "(w:YValue,j:yValue,wf:YValue)DataRef");
            a.item("ItemRef", "(w:Item,j:item,wf:Item)DataRef");
            a.item("Series", "(j:_internalSeries)ExportedType:Series");
            a.item("SeriesName", "String");
        }
        static d(a) {
            CalloutSeriesSelectingEventArgsDescriptionMetadata.b(a);
            a.ae("CalloutSeriesSelectingEventArgs", () => new CalloutSeriesSelectingEventArgsDescription());
            a.ad("CalloutSeriesSelectingEventArgs", CalloutSeriesSelectingEventArgsDescriptionMetadata.a);
        }
    }
    CalloutSeriesSelectingEventArgsDescriptionMetadata.$t = markType(CalloutSeriesSelectingEventArgsDescriptionMetadata, 'CalloutSeriesSelectingEventArgsDescriptionMetadata');
    CalloutSeriesSelectingEventArgsDescriptionMetadata.a = null;
    return CalloutSeriesSelectingEventArgsDescriptionMetadata;
})();
